disableAdvertising method
Pauses player advertising, note that a running ad will finish if this method is called
Implementation
Future<void> disableAdvertising() async {
await _methodChannel.invokeMethod<void>('disableAdvertising');
}
Pauses player advertising, note that a running ad will finish if this method is called
Future<void> disableAdvertising() async {
await _methodChannel.invokeMethod<void>('disableAdvertising');
}