setAutoQuality method
Sets the video quality to Auto. Auto quality will be determined by the height of the video element
Implementation
Future<void> setAutoQuality() async {
await _methodChannel.invokeMethod<void>('setAutoQuality');
}
Sets the video quality to Auto. Auto quality will be determined by the height of the video element
Future<void> setAutoQuality() async {
await _methodChannel.invokeMethod<void>('setAutoQuality');
}