setMacros method

Future<void> setMacros(
  1. String macrosJsonString
)

Sets custom macros. The method uses key value pairs of macros { key: value }. Please note that Connatix Macros will NOT we overridden

  • macrosJsonString representing key value pairs of macros to be substituted in lineItems URLs before calling for VAST Ads. If any of the macro keys match the "Connatix macros" (ex: height, page_url), the values provided programmatically by the user will NOT override the values detected by the player, only for the externally loaded line items

Implementation

Future<void> setMacros(String macrosJsonString) async {
  await _methodChannel.invokeMethod<void>('setMacros', macrosJsonString);
}