toggleSubtitles method

Future<void> toggleSubtitles(
  1. bool shouldShow
)

Shows or hides the video subtitles based on the given boolean. Value is necessary

  • shouldShow Boolean indicating whether to show subtitles or not

Implementation

Future<void> toggleSubtitles(bool shouldShow) async {
  await _methodChannel.invokeMethod<void>('toggleSubtitles', shouldShow);
}