setLayout method

Future<void> setLayout(
  1. int layoutType
)

Forces the story player to render in chosen orientation mode. Orientation mode will be changed based on the parameter received

  • layoutType to change the orientation to
  • 0 is Portrait
  • 1 is Landscape

Implementation

Future<void> setLayout(int layoutType) async {
  await _methodChannel.invokeMethod<void>('setLayout', layoutType);
}